import optimizeClientRects from "./optimize-client-rects";
const isClientRectInsidePageRect = (clientRect, pageRect) => {
    if (clientRect.top < pageRect.top) {
        return false;
    }
    if (clientRect.bottom > pageRect.bottom) {
        return false;
    }
    if (clientRect.right > pageRect.right) {
        return false;
    }
    if (clientRect.left < pageRect.left) {
        return false;
    }
    return true;
};
const getPageBorders = (page) => {
    const style = getComputedStyle(page.node);
    return {
        borderTop: parseFloat(style.borderTopWidth.replace('px', '')),
        borderLeft: parseFloat(style.borderLeftWidth.replace('px', '')),
        borderBottom: parseFloat(style.borderBottomWidth.replace('px', '')),
        borderRight: parseFloat(style.borderRightWidth.replace('px', '')),
    };
};
const getClientRects = (range, pages, shouldOptimize = true) => {
    const clientRects = Array.from(range.getClientRects());
    const rects = [];
    for (const clientRect of clientRects) {
        for (const page of pages) {
            const pageRect = page.node.getBoundingClientRect();
            const { borderTop, borderBottom, borderLeft, borderRight } = getPageBorders(page);
            if (isClientRectInsidePageRect(clientRect, pageRect) &&
                clientRect.top >= borderTop &&
                clientRect.bottom >= borderBottom &&
                clientRect.width > 0 &&
                clientRect.height > 0 &&
                clientRect.width < pageRect.width - borderLeft - borderRight &&
                clientRect.height < pageRect.height - borderTop - borderBottom) {
                const highlightedRect = {
                    top: clientRect.top + page.node.scrollTop - pageRect.top - borderTop,
                    left: clientRect.left + page.node.scrollLeft - pageRect.left - borderLeft,
                    width: clientRect.width,
                    height: clientRect.height,
                    pageNumber: page.number,
                };
                if (highlightedRect.top >= borderTop && highlightedRect.left >= borderLeft) {
                    rects.push(highlightedRect);
                }
            }
        }
    }
    return shouldOptimize ? optimizeClientRects(rects) : rects;
};
export default getClientRects;
//# sourceMappingURL=get-client-rects.js.map